%Agecorrs
% Calculate all correlations within the site.
% Unlike incore correlations, these are not required to be uniquely
% concentration or flux.

% Generate the data array
build_agerecs

% A colour map for the patchwork plots
cmap = redblue ;

% Clear some variables
clear numrec
clear recnames
clear corr_out
clear t_summary
clear typesum
clear corrmat_names
clear corrmat_types
clear corrmat_fishtypes
clear fishtype_site

% FIRST, NOT DETRENDED

if makefigs
f1 = figure ;
set(gcf,'Position',[10 200 2500 2000],'Color','w') ;
end

% Check the number of records vs. age at the site 

numrec = size(agerecs,1);
recnames = agerecs(:,1) ;

% Initialize variables
corr_out=zeros(numrec,numrec,3);
allpairs_age={[] [] [] [] [] []} ;

% Loop over all the possible combinations within the site
for i=1:numrec ;
    for j=1:numrec ;
        [typesum,typeid,fishtype]=checktype(agerecs{i,3},agerecs{j,3});
        rec1 = agerecs{i,2};
        rec2 = agerecs{j,2};
        % check for sufficient overlap of time
        latest_comm = min(max(rec2(:,1)),max(rec1(:,1))) ;
        earliest_comm = max(min(rec2(:,1)),min(rec1(:,1))) ;
        overlapind_1 = find(rec1(:,1) > earliest_comm & rec1(:,1) < latest_comm) ;
        overlapind_2 = find(rec2(:,1) > earliest_comm & rec2(:,1) < latest_comm) ;
        if length(overlapind_1) > sig_n_lim && length(overlapind_2) > sig_n_lim
            corr_out(i,j,:) = calc_corrs(rec1,rec2);
            allpairs_age = [allpairs_age; {[agerecs{i,1} ' v. ' agerecs{j,1}], typeid, fishtype,corr_out(i,j,1),corr_out(i,j,2),corr_out(i,j,3)}];
            % plot the records as sent to the calculation script
            if makefigs 
            subplot(numrec,numrec,(i)+numrec*(j-1))
            plotyy(rec1(:,1),rec1(:,2),rec2(:,1),rec2(:,2))
            end
        end
        corrmat_names{i,j} = [agerecs{i,1} ' v. ' agerecs{j,1}];
        corrmat_types(i,j) = typeid;
        corrmat_fishtypes(i,j) = fishtype;
    end
end

if makefigs
% Print out the matrix of curve plots
export_fig(sprintf('%s/figures/age.curves.pdf', sitename), '-pdf', '-painters')
end

% Identify which correlations are significant, in terms of p and n
sig_p_n = corr_out(:,:,2) < sig_p_lim & corr_out(:,:,3) > sig_n_lim ;
% Check that both directions of interpolation produce significance
sig_sym = sig_p_n .* sig_p_n' ;

% Create a 2d array of r values
corrs = squeeze(corr_out(:,:,1)) ;
% Set diagonal (self-correlation) elements to 0 (needed for recpair count)
corrs(1:numrec+1:numrec^2) = 0 ;
% Do the same for the sig_sym mask (needed for p and n)
sig_sym(1:numrec+1:numrec^2) = 0 ;

% Create an array of only the significant r values
sigcorrs = squeeze(corr_out(:,:,1)) .* sig_sym ;
% Likewise for p and n
sigcorrs_p = squeeze(corr_out(:,:,2) .* sig_sym) ;
sigcorrs_n = squeeze(corr_out(:,:,3) .* sig_sym) ;
% Likewise for the fishtypes
sigfishtypes = corrmat_fishtypes .* sig_sym ;
% Identify the positive fish correlations
pos_sigcorrs = sigcorrs > 0;
pos_sigfishtypes = sigfishtypes .* pos_sigcorrs;

avg_sigcorrs = (sigcorrs+sigcorrs')./2 ;
avg_sigcorrs_p = (sigcorrs_p+sigcorrs_p')./2 ;
% Locate the significant fish correlations (upper-diagonal matrix half only)
ind_fishcorrs = find(triu(sigfishtypes));


% Write out variable pairs and correlation statistics in a list
ind=find(sigcorrs);
ind1=find(sigcorrs & corrmat_types ==1);
ind2=find(sigcorrs & corrmat_types ==2);
ind3=find(sigcorrs & corrmat_types ==3);
ind4=find(sigcorrs & corrmat_types ==4);
ind5=find(sigcorrs & corrmat_types ==5);
ind6=find(sigcorrs & corrmat_types ==6);
pair_names = corrmat_names(ind);
r_values = sigcorrs(ind) ;
p_values = sigcorrs_p(ind) ;
n_tested = sigcorrs_n(ind) ;
sigcorrs_table = table(pair_names, r_values, p_values, n_tested);
writetable(sigcorrs_table,sprintf('%s/tables/age.corrs.txt', sitename));

% Add up the number of records tested
recpairs = [floor(length(find(corrs & corrmat_types ==1))./2), 
    floor(length(find(corrs & corrmat_types ==2))./2),
    floor(length(find(corrs & corrmat_types ==3))./2),
    floor(length(find(corrs & corrmat_types ==4))./2),
    floor(length(find(corrs & corrmat_types ==5))./2),
    floor(length(find(corrs & corrmat_types ==6))./2)];
% Add number of significant correlations
sigcorr_no = [floor(length(ind1)./2),
    floor(length(ind2)./2),
    floor(length(ind3)./2),
    floor(length(ind4)./2),
    floor(length(ind5)./2),
    floor(length(ind6)./2)];


% Plot significant correlations
if makefigs
f2 = figure ;
set(gcf,'Position',[10 200 600 500],'Color','w') ;
imagesc(sigcorrs,[-1 1])
colormap(cmap)
xticks([1:1:numrec]);
xticklabels(recnames);
yticks([1:1:numrec]);
yticklabels(recnames);
xtickangle(45);
title(sprintf('%s all age-based significant correlations', sitename));
export_fig(sprintf('%s/figures/age.corrs.pdf', sitename), '-pdf', '-opengl')
end





% THEN, DETRENDED

% Initialize variables
corr_out=zeros(numrec,numrec,3);
allpairs_age_dt={[] [] [] [] [] []} ;

% Loop over all the possible combinations within the site
for i=1:numrec ;
    for j=1:numrec ;
        [typesum,typeid,fishtype]=checktype(agerecs{i,3},agerecs{j,3});
        rec1 = agerecs{i,2};
        rec2 = agerecs{j,2};
        % check for sufficient overlap of time
        latest_comm = min(max(rec2(:,1)),max(rec1(:,1))) ;
        earliest_comm = max(min(rec2(:,1)),min(rec1(:,1))) ;
        overlapind_1 = find(rec1(:,1) > earliest_comm & rec1(:,1) < latest_comm) ;
        overlapind_2 = find(rec2(:,1) > earliest_comm & rec2(:,1) < latest_comm) ;
        if length(overlapind_1) > sig_n_lim && length(overlapind_2) > sig_n_lim
            corr_out(i,j,:) = calc_corrs_dt(rec1,rec2);
            allpairs_age_dt = [allpairs_age_dt; {[agerecs{i,1} ' v. ' agerecs{j,1}], typeid, fishtype,corr_out(i,j,1),corr_out(i,j,2),corr_out(i,j,3)}];
        end
        corrmat_types(i,j) = typeid;
    end
end

% Identify which correlations are significant, in terms of p and n
sig_p_n = corr_out(:,:,2) < sig_p_lim & corr_out(:,:,3) > sig_n_lim ;
% Check that both directions of interpolation produce significance
sig_sym = sig_p_n .* sig_p_n' ;


% Create a 2d array of r values
corrs = squeeze(corr_out(:,:,1)) ;
% Set diagonal (self-correlation) elements to 0 (needed for recpair count)
corrs(1:numrec+1:numrec^2) = 0 ;
% Do the same for the sig_sym mask (needed for p and n)
sig_sym(1:numrec+1:numrec^2) = 0 ;

% Create an array of only the significant r values
sigcorrs = squeeze(corr_out(:,:,1)) .* sig_sym ;
% Likewise for p and n
sigcorrs_p = squeeze(corr_out(:,:,2) .* sig_sym) ;
sigcorrs_n_dt = squeeze(corr_out(:,:,3) .* sig_sym) ;
% Likewise for the fishtypes
sigfishtypes_dt = corrmat_fishtypes .* sig_sym ;
% Identify the positive fish correlations
pos_sigcorrs = sigcorrs > 0;
pos_sigfishtypes_dt = sigfishtypes .* pos_sigcorrs;

avg_sigcorrs_dt = (sigcorrs+sigcorrs')./2 ;
avg_sigcorrs_p_dt = (sigcorrs_p+sigcorrs_p')./2 ;
% Locate the significant fish correlations (upper-diagonal matrix half only)
ind_fishcorrs_dt = find(triu(sigfishtypes_dt));

% Write out variable pairs and correlation statistics in a list
ind=find(sigcorrs);
ind1=find(sigcorrs & corrmat_types ==1);
ind2=find(sigcorrs & corrmat_types ==2);
ind3=find(sigcorrs & corrmat_types ==3);
ind4=find(sigcorrs & corrmat_types ==4);
ind5=find(sigcorrs & corrmat_types ==5);
ind6=find(sigcorrs & corrmat_types ==6);
pair_names = corrmat_names(ind);
r_values = sigcorrs(ind) ;
p_values = sigcorrs_p(ind) ;
n_tested = sigcorrs_n_dt(ind) ;
sigcorrs_dt_table = table(pair_names, r_values, p_values, n_tested);
writetable(sigcorrs_dt_table,sprintf('%s/tables/age.corrs_dt.txt', sitename));

% Add number of significant detrended correlations
sigcorr_dt_no = [floor(length(ind1)./2),
    floor(length(ind2)./2),
    floor(length(ind3)./2),
    floor(length(ind4)./2),
    floor(length(ind5)./2),
    floor(length(ind6)./2)];

if makefigs
% Plot significant correlations
f2 = figure ;
set(gcf,'Position',[10 200 numrec*100 numrec*85],'Color','w') ;
imagesc(sigcorrs,[-1 1])
colormap(cmap)
xticks([1:1:numrec]);
xticklabels(recnames);
yticks([1:1:numrec]);
yticklabels(recnames);
xtickangle(45);
title(sprintf('%s all age-based significant detrended correlations', sitename));
export_fig(sprintf('%s/figures/age.corrs_dt.pdf', sitename), '-pdf', '-opengl')
end

% Add up by fishtype
% Rows correspond to fishtype vector
% Columns are: pairs tested, significant pairs, significant dt pairs
allpairs_fishtypes = cell2mat(allpairs_age(:,3));
for i=1:13
    fishtype_site(i,:) = [floor(length(find(allpairs_fishtypes == i))/2), floor(length(find(sigfishtypes == i))/2), floor(length(find(pos_sigfishtypes == i))/2), floor(length(find(sigfishtypes_dt == i))/2), floor(length(find(pos_sigfishtypes_dt == i))/2)];
end

goodrecs = size(allpairs_age,1);
allpairs_age = allpairs_age(2:goodrecs,:);
goodrecs = size(allpairs_age_dt,1);
allpairs_age_dt = allpairs_age_dt(2:goodrecs,:);
save(sprintf('%s/allpairs_age.mat',sitename),'allpairs_age','allpairs_age_dt');

t_summary = table(recpairs, sigcorr_no, sigcorr_dt_no) ; 
t_summary.Properties.VariableNames = {'RecordPairs','Significant', 'Significant_dt'} ;
t_summary.Properties.RowNames = {'FishFish','FishBgc','BgcBgc','FishPhys','PhysBgc','PhysPhys'} ;
writetable(t_summary,sprintf('%s/tables/age.summary.txt', sitename));

fishtype_site_table = table(fishtype_site(:,1),fishtype_site(:,2),fishtype_site(:,3),round(fishtype_site(:,2)./fishtype_site(:,1).*100),fishtype_site(:,4),fishtype_site(:,5),round(fishtype_site(:,4)./fishtype_site(:,1).*100)) ;
fishtype_site_table.Properties.RowNames = fishtype_var ;
fishtype_site_table.Properties.VariableNames = {'Pairs', 'Sig', 'Sig_Pos', 'Sig_pct', 'Sig_dt', 'Sig_dt_Pos','Sig_dt_pct'} ;
writetable(fishtype_site_table,sprintf('%s/tables/fishtype.summary.txt', sitename));

fishsigcorrs_array = [avg_sigcorrs(ind_fishcorrs),avg_sigcorrs_p(ind_fishcorrs),sigcorrs_n(ind_fishcorrs)];
fishsigcorrs_table = table(avg_sigcorrs(ind_fishcorrs),avg_sigcorrs_p(ind_fishcorrs),sigcorrs_n(ind_fishcorrs));
fishsigcorrs_table.Properties.RowNames = corrmat_names(ind_fishcorrs)' ;
fishsigcorrs_table.Properties.VariableNames = {'r','p','n'}  ;

fishsigcorrs_dt_array = [avg_sigcorrs_dt(ind_fishcorrs_dt) avg_sigcorrs_p_dt(ind_fishcorrs_dt) sigcorrs_n_dt(ind_fishcorrs_dt)];
fishsigcorrs_dt_table = table(avg_sigcorrs_dt(ind_fishcorrs_dt),avg_sigcorrs_p_dt(ind_fishcorrs_dt),sigcorrs_n_dt(ind_fishcorrs_dt));
fishsigcorrs_dt_table.Properties.RowNames = corrmat_names(ind_fishcorrs_dt)' ;
fishsigcorrs_dt_table.Properties.VariableNames = {'r_dt','p_dt','n_dt'}  ;



if genlatex
    input.data = t_summary ;
    input.dataFormat = {'%.0f'};
    sitesummarytable = latexTable(input)
    input.data = fishtype_site_table ;
    input.dataFormat = {'%.0f'};
    sitefishtypetable = latexTable(input)
    input.data = fishsigcorrs_table ;
    input.dataFormat = {'%.3f'};
    sitefishsigcorrstable = latexTable(input) ;
    input.dataFormat = {'%.3f'};
    input.data = fishsigcorrs_dt_table ;
    sitefishsigcorrsdttable = latexTable(input) ;
end


