% Loops through the analysis of all sites
% Initialize
close all
clear all

% User-defined variables

% P-value to use as significane threshold
sig_p_lim = 0.05 ;
% Minimum number of measurements to consider significant
sig_n_lim = 8 ; 

% Option to generate latex tables
genlatex = 1;

% Option to generate plots (requires export_fig)
makefigs = 0;

% END User input


% Initialize summary arrays
incore_sums = zeros(6,3,8);
agecorr_sums = zeros(6,3,8);
fishtype_sums = zeros(13,5,8);
fishsigcorrs = {};
fishsigcorrs_dt = {};
% Site names
allsites = {'callao','effingham','guaymas','mejillones','pisco','saanich','santabarbara','soledad'};

% Fishtype names
fishtype_var = {'TOC','TN','CN','Carb','Opal','d15N','d13C','ForamAssemb','Productivity','BWO2','Quartz','SST','Al'} ;
    
% Loop through all sites
for siteno=1:8;
    sitename=allsites{siteno}
    clear cores
    incore
    % Save sums, m = vartype, n = recpairs,sigcorr,sigcorr_dt 
    incore_sums(:,:,siteno)= [sum(recpairs_sum,2), sum(sigcorr_no_sum,2), sum(sigcorr_dt_no_sum,2)] ;
    close all
    agecorrs
    % Save sums, m = vartype, n = recpairs,sigcorr,sigcorr_dt 
    agecorr_sums(:,:,siteno)= [recpairs, sigcorr_no, sigcorr_dt_no] ;
    fishtype_sums(:,:,siteno)=fishtype_site ;
    fishsigcorrs{siteno} = fishsigcorrs_array ;
    fishsigcorrs_dt{siteno} = fishsigcorrs_dt_array ;
    if genlatex
        % Save summary tables into a cell array for printout
        sitesummaries{siteno} = sitesummarytable
        sitefishtypes{siteno} = sitefishtypetable
        sitefishcorrs{siteno} = sitefishsigcorrstable
        sitefishcorrs_dt{siteno} = sitefishsigcorrsdttable
    end
    close all
end

all_recpairs = sum(incore_sums(:,1,:),3) ;
all_sig      = sum(incore_sums(:,2,:),3) ;
all_sigdt    = sum(incore_sums(:,3,:),3) ;
t_all_incore = table(all_recpairs, all_sig, round(all_sig./all_recpairs.*100,0), all_sigdt, round(all_sigdt./all_recpairs.*100,0)) ; 
t_all_incore.Properties.VariableNames = {'RecordPairs','Significant','SignificantPct', 'Significant_dt','Significant_dtPct'} ;
t_all_incore.Properties.RowNames = {'FishFish','FishBgc','BgcBgc','FishPhys','PhysBgc','PhysPhys'} ;
t_all_incore
writetable(t_all_incore,'allsites.incore.summary.txt');


all_recpairs = sum(agecorr_sums(:,1,:),3) ;
all_sig      = sum(agecorr_sums(:,2,:),3) ;
all_sigdt    = sum(agecorr_sums(:,3,:),3) ;
t_all_agecorr = table(all_recpairs, all_sig, round(all_sig./all_recpairs.*100,0), all_sigdt, round(all_sigdt./all_recpairs.*100,0)) ; 
t_all_agecorr.Properties.VariableNames = {'RecordPairs','Significant','SignificantPct', 'Significant_dt','Significant_dtPct'} ;
t_all_agecorr.Properties.RowNames = {'FishFish','FishBgc','BgcBgc','FishPhys','PhysBgc','PhysPhys'} ;
t_all_agecorr
writetable(t_all_agecorr,'allsites.agecorr.summary.txt');

all_fishtypes = sum(fishtype_sums,3) ;
fishtype_table = table(all_fishtypes(:,1),all_fishtypes(:,2),all_fishtypes(:,3),round(all_fishtypes(:,2)./all_fishtypes(:,1).*100),all_fishtypes(:,4),all_fishtypes(:,5),round(all_fishtypes(:,4)./all_fishtypes(:,1).*100)) ;
fishtype_table.Properties.RowNames = fishtype_var ;
fishtype_table.Properties.VariableNames = {'Pairs', 'Sig', 'Sig_Pos', 'Sig_pct', 'Sig_dt', 'Sig_dt_Pos','Sig_dt_pct'}
writetable(fishtype_table,'allsites.fishtypes.summary.txt');

% This generates Latex tables that can be copied and pasted into a Latex
% manuscript
if genlatex
    input.data = t_all_incore ;
    input.dataFormat = {'%.0f'};
    latexTable(input);
    input.data = t_all_agecorr ;
    input.dataFormat = {'%.0f'};
    latexTable(input);
    input.data = fishtype_table ;
    input.dataFormat = {'%.0f'};
    latexTable(input);

    save('all.by.site.tables.mat','sitesummaries','sitefishtypes', 'sitefishcorrs','sitefishcorrs_dt')
end
