%This file gives all full-length records

%First, list all data by cores
%c = core number
%t = records on time axes
%d = records on depth axes

%Record types
%Odd numbers are concentrations or indexes, even numbers are fluxes
%0 = year model 
%1 = fish content 
%2 = fish flux 
%31/32 = TOC content /flux
%33/34 = TN
%35  = C:N
%37/38 = Carb
%39/40 = Opal
%41 = d15N
%43 = d13C
%45 = Foram assemblage
%47 = Productivity
%49 = Oxygen indicator
%101 = physical content 
%102 = physical flux 
%103/104 = quartz
%105/106 = SST
%107/108 = Al

run callao/core106kl
c1 = '106KL' ;

d1 = [] ;

t1 = {
    'sst' , tdat.sst, 105
    } ;
% ---

run callao/odp1228
c2 = 'ODP1228' ;

d2 = {
    'year' , ddat.year , 0 ;
    'd15N' , ddat.d15n , 41;
    'TN %' , ddat.n , 33 ;
    } ;

t2 = [] ;

% ---

run callao/w7706
c3 = 'W7706-40' ;

d3 = {
    'year' , ddat.year , 0 ;
    'd15N' , ddat.d15n , 41 ;
    'TN %' , ddat.n , 33 ;
    } ;

t3 = [] ;

% ---


run callao/so78
c4 = 'SO78-173-4' ;

d4 = {
    'year' , ddat.year , 0 ;
    'TOC %' , ddat.toc , 31 ;
    'SST' , ddat.sst , 105 ;
    } ;

t4 = [] ;

% ---



run callao/b0405_13
c5 = 'B0405-13' ;

% SPECIAL: only use post-transition
% define cutoff depth
cutoffd = 32 ;
ind_tn=find(ddat.tn(:,1) < cutoffd) ;
ind_toc=find(ddat.toc(:,1) < cutoffd) ;
ind_cc=find(ddat.cc(:,1) < cutoffd) ;
ind_qtz=find(ddat.qtz(:,1) < cutoffd) ;
ind_anch3=find(ddat.anch3(:,1) < cutoffd) ;
ind_hake2=find(ddat.hake2(:,1) < cutoffd) ;
ind_sard=find(ddat.sard(:,1) < cutoffd) ;
ind_jack=find(ddat.jack(:,1) < cutoffd) ;



d5 = {
    'year' , ddat.year , 0 ;
%    'Anch #/g' , ddat.anch ; removed because duplicated below
%    'Hake #/g' , ddat.hake ;
    'TN %' , ddat.tn(ind_tn,:) , 33 ;
    'TOC %' , ddat.toc(ind_toc,:) , 31 ;
    'Calcite %' , ddat.cc(ind_cc,:) , 37 ;
    'Quartz %' , ddat.qtz(ind_qtz,:) , 103 ;
%    'Anch #/g', ddat.anch2 ; 
    'Anch #/g', ddat.anch3(ind_anch3,:) , 1 ;
    'Hake #/g' , ddat.hake2(ind_hake2,:) , 1 ;
    'Sard #/g' , ddat.sard(ind_sard,:) , 1 ;
    'JackMack #/g' , ddat.jack(ind_jack,:) , 1 ;
    } ;

t5 = {
    'd15N' , tdat.d15n , 41 ;
%    'TOC %' , tdat.toc ; removed because duplicated above
    } ;
% ---





run callao/c0329
c6 = 'C0329' ;

% SPECIAL: only use post-transition
% define cutoff depth
cutoffd = 17 ;
ind_anch=find(ddat.anch(:,1) < cutoffd) ;
ind_hake=find(ddat.hake(:,1) < cutoffd) ;
ind_sard=find(ddat.sard(:,1) < cutoffd) ;
ind_oth=find(ddat.oth(:,1) < cutoffd) ;
ind_all=find(ddat.all(:,1) < cutoffd) ;
ind_pfish=find(ddat.pfish(:,1) < cutoffd) ;
ind_tn=find(ddat.tn(:,1) < cutoffd) ;
ind_toc=find(ddat.toc(:,1) < cutoffd) ;
ind_cc=find(ddat.cc(:,1) < cutoffd) ;
ind_opal=find(ddat.opal(:,1) < cutoffd) ;


d6 = {
    'year' , ddat.year , 0 ;
    'Anch #/g' , ddat.anch(ind_anch,:) , 1 ;
    'Hake #/g' , ddat.hake(ind_hake,:) , 1 ;
    'Sard #/g' , ddat.sard(ind_sard,:) , 1 ;
    'Other #/g' , ddat.oth(ind_oth,:) , 1 ;
    'All #/g' , ddat.all(ind_all,:) , 1 ;
    'P fish ppm' ,ddat.pfish(ind_pfish,:) , 1 ;  
    'TOC %' , ddat.toc(ind_toc,:) , 31  ;
    'TN %' , ddat.tn(ind_tn,:) , 33 ;
    'Calcite %' , ddat.cc(ind_cc,:) , 37 ;
    'Opal %' , ddat.opal(ind_opal,:) , 39 ;
    } ;

t6 =  [] ;

% ---


% Generate the cell-array for all the callao cores

cores = {
    c1, d1 , t1  ;
    c2, d2 , t2  ;
    c3, d3 , t3  ;
    c4, d4 , t4  ;
    c5, d5 , t5  ;
    c6, d6 , t6  ;
    } ;
    
    