%First, list all data by cores
%c = core number
%t = records on time axes
%d = records on depth axes

%Record types
%Odd numbers are concentrations or indexes, even numbers are fluxes
%0 = year model 
%1 = fish content 
%2 = fish flux 
%31/32 = TOC content /flux
%33/34 = TN
%35  = C:N
%37/38 = Carb
%39/40 = Opal
%41 = d15N
%43 = d13C
%45 = Foram assemblage
%47 = Productivity
%49 = Oxygen indicator
%101 = physical content 
%102 = physical flux 
%103/104 = quartz
%105/106 = SST
%107/108 = Al

run pisco/B040506
c1 = 'B0405-06' ;

% SPECIAL: only use post-transition
% define cutoff depth
cutoffd = 22 ;
ind_tn=find(ddat.tn(:,1) < cutoffd) ;
ind_toc=find(ddat.toc(:,1) < cutoffd) ;
ind_calc=find(ddat.calc(:,1) < cutoffd) ;
ind_quar=find(ddat.quar(:,1) < cutoffd) ;
ind_n15=find(ddat.n15(:,1) < cutoffd) ;
ind_sst=find(ddat.sst(:,1) < cutoffd) ;

d1 = {
    'Year' , ddat.year, 0 ;
    'TOC %' , ddat.toc(ind_toc,:), 31 ;
    'TN %' , ddat.tn(ind_tn,:), 33 ;
    'Calcite %' , ddat.calc(ind_calc,:), 37 ;
    'Quartz %' , ddat.quar(ind_quar,:), 103 ;
    'N-15 per mill' , ddat.n15(ind_n15,:), 41 ;
    'SST C' , ddat.sst(ind_sst,:), 105 ;
    } ;

% SPECIAL: only use post-transition
% define cutoff depth
cutofft = 1830 ;
ind_anch=find(tdat.anch(:,1) > cutofft) ;
ind_hake=find(tdat.hake(:,1) > cutofft) ;
ind_sar=find(tdat.sar(:,1) > cutofft) ;
ind_jack=find(tdat.jack(:,1) > cutofft) ;
ind_tot=find(tdat.tot(:,1) > cutofft) ;


t1 = {
    'Anchovy Scales # g^-1' , tdat.anch(ind_anch,:), 1 ;
    'Hake Scales # g^-1' , tdat.hake(ind_hake,:), 1 ;
    'Sardine Scales # g^-1' , tdat.sar(ind_sar,:), 1 ;
    'Jack Mackerel Scales # g^-1' , tdat.jack(ind_jack,:), 1 ;
    'Total Scales # g^-1' , tdat.tot(ind_tot,:), 1 ;
    } ;



run pisco/B050614
c2 = 'B0506-14' ;

% SPECIAL: only use post-transition
% define cutoff depth
cutoffd = 60 ;
ind_toc=find(ddat.toc(:,1) < cutoffd) ;
ind_si=find(ddat.si(:,1) < cutoffd) ;
ind_remo=find(ddat.remo(:,1) < cutoffd) ;
ind_15n=find(ddat.n15(:,1) < cutoffd) ;
ind_anch=find(ddat.anch(:,1) < cutoffd) ;
ind_hake=find(ddat.hake(:,1) < cutoffd) ;
ind_sar=find(ddat.sar(:,1) < cutoffd) ;
ind_jack=find(ddat.jack(:,1) < cutoffd) ;
ind_tot=find(ddat.tot(:,1) < cutoffd) ;

d2 = {
    'Year' , ddat.year, 0 ;
    'TOC %' , ddat.toc(ind_toc,:), 31 ;
    'Anchovy Scales # g^-1' , ddat.anch(ind_anch,:), 1 ;
    'Hake Scales # g^-1' , ddat.hake(ind_hake,:), 1 ;
    'Sardine Scales # g^-1' , ddat.sar(ind_sar,:), 1 ;
    'Jack Mackerel Scales # g^-1' , ddat.jack(ind_jack,:), 1 ;
    'Total Scales # g^-1' , ddat.tot(ind_tot,:), 1 ;
    'N-15 per mill' , ddat.n15(ind_n15,:), 41 ;
    'Si %' , ddat.si(ind_si,:), 39 ;
    'Re/Mo' , ddat.remo(ind_remo,:), 49 ;

    } ;

t2 = [] ;



run pisco/B0513
c3 = 'B05-13' ;

d3 = {
    'Year' , ddat.year, 0 ;
    'TOC %' , ddat.toc, 31 ;
    'Anchovy Scales # g^-1' , ddat.anch, 1 ;
    'Hake Scales # g^-1' , ddat.hake, 1 ;
    'Sardine Scales # g^-1' , ddat.sar, 1 ;
    'Jurel Scales # g^-1' , ddat.jur, 1 ;
    'Total Scales # g^-1' , ddat.tot, 1 ;
    } ;

t3 = [] ;

% Generate the cell-array for all the pisco cores

cores = {
    c1, d1 , t1  ;
    c2, d2 , t2  ;
    c3, d3 , t3  ;
    } ;
    